@@ -1,3 +1,6 @@
+# Copyright Contributors to the Amundsen project.
+# SPDX-License-Identifier: Apache-2.0
+
 from typing import List, Optional
 
 import attr
@@ -30,6 +33,19 @@ class TagSchema(AttrsSchema):
         register_as_scheme = True
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class Badge:
+    badge_name: str = attr.ib()
+    category: str = attr.ib()
+    badge_type: str = attr.ib()
+
+
+class BadgeSchema(AttrsSchema):
+    class Meta:
+        target = Badge
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Watermark:
     watermark_type: Optional[str] = None
